summaryrefslogtreecommitdiffstats
path: root/contrib/cvs/lib/system.h
diff options
context:
space:
mode:
authorobrien <obrien@FreeBSD.org>2008-01-13 05:49:32 +0000
committerobrien <obrien@FreeBSD.org>2008-01-13 05:49:32 +0000
commit55b663837dd12bbe5836969ac2a3f052a9028ea5 (patch)
tree8d8aae4a8bb167db64e23bb7f76f39014f36d45f /contrib/cvs/lib/system.h
parent8416bda1d23bda4666a5b880a9d78eccaa640036 (diff)
downloadFreeBSD-src-55b663837dd12bbe5836969ac2a3f052a9028ea5.zip
FreeBSD-src-55b663837dd12bbe5836969ac2a3f052a9028ea5.tar.gz
Import cvs-1.11.22 onto vendor branch.
Diffstat (limited to 'contrib/cvs/lib/system.h')
-rw-r--r--contrib/cvs/lib/system.h22
1 files changed, 13 insertions, 9 deletions
diff --git a/contrib/cvs/lib/system.h b/contrib/cvs/lib/system.h
index a18dff8..3956f37 100644
--- a/contrib/cvs/lib/system.h
+++ b/contrib/cvs/lib/system.h
@@ -491,18 +491,22 @@ extern unsigned char WNT_filename_classes[];
Windows NT, you can use either / or \. */
# define ISDIRSEP(c) (FOLD_FN_CHAR(c) == '/')
# define ISABSOLUTE(s) (ISDIRSEP(s[0]) || FOLD_FN_CHAR(s[0]) >= 'a' && FOLD_FN_CHAR(s[0]) <= 'z' && s[1] == ':' && ISDIRSEP(s[2]))
# else /* ! WOE32 */
/* As far as I know, just Macintosh OS X can make it here,
* but since the OS X fold just folds a-z into A-Z or visa-versa, I'm just
* allowing it to be used for any case insensitive system which we aren't
* yet making other specific folds or exceptions for (basically, anything
* case insensitive other than Windows, where \ and C:\ style absolute paths
* also need to be accounted for).
*
* Under Mac OS X, filenames are case-insensitive.
*/
+# if defined(USE_VMS_FILENAMES)
+# define FOLD_FN_CHAR(c) (VMS_filename_classes[(unsigned char) (c)])
+extern unsigned char VMS_filename_classes[];
+# else
# define FOLD_FN_CHAR(c) (OSX_filename_classes[(unsigned char) (c)])
extern unsigned char OSX_filename_classes[];
+# endif
# endif /* __CYGWIN32__ || WOE32 */
/* The following need to be declared for all case insensitive filesystems.
OpenPOWER on IntegriCloud
@@ -491,18 +491,22 @@ extern unsigned char WNT_filename_classes[];
# define ISDIRSEP(c) (FOLD_FN_CHAR(c) == '/')
# define ISABSOLUTE(s) (ISDIRSEP(s[0]) || FOLD_FN_CHAR(s[0]) >= 'a' && FOLD_FN_CHAR(s[0]) <= 'z' && s[1] == ':' && ISDIRSEP(s[2]))
-# else /* ! WOE32 */
- /* As far as I know, just Macintosh OS X can make it here,
- * but since the OS X fold just folds a-z into A-Z or visa-versa, I'm just
- * allowing it to be used for any case insensitive system which we aren't
- * yet making other specific folds or exceptions for (basically, anything
- * case insensitive other than Windows, where \ and C:\ style absolute paths
- * also need to be accounted for).
- *
- * Under Mac OS X, filenames are case-insensitive.
+# else /* !__CYGWIN32__ && !WOE32 */
+ /* As far as I know, only Macintosh OS X & VMS make it here, but any
+ * platform defining FILENAMES_CASE_INSENSITIVE which isn't WOE32 or
+ * piggy-backing the same could, in theory. Since the OS X fold just folds
+ * A-Z into a-z, I'm just allowing it to be used for any case insensitive
+ * system which we aren't yet making other specific folds or exceptions for.
+ * WOE32 needs its own class since \ and C:\ style absolute paths also need
+ * to be accounted for.
*/